Pseudo-Class | Description
--- | ---
active | To-Do
bottom | To-Do
checked | To-Do
closable | To-Do
closed | To-Do
default | To-Do
disabled | To-Do
editable | To-Do
enabled | To-Do
exclusive | To-Do
first | To-Do
flat | To-Do
floatable | To-Do
focus | To-Do
horizontal | To-Do
hover | To-Do
last | To-Do
left | To-Do
maximized | To-Do
middle | To-Do
minimized | To-Do
movable | To-Do
no-frame | To-Do
non-exclusive | To-Do
off | To-Do
on | To-Do
only-one | To-Do
open | To-Do
next-selected | To-Do
pressed | To-Do
previous-selected | To-Do
read-only | To-Do
right | To-Do
selected | To-Do
top | To-Do
unchecked | To-Do
vertical | To-Do
window | To-Do